#!/bin/csh


# attempt to load cruise variables if they're not already loaded
if (! $?HOME_DIR ) then
        set ROOT_DIR =
        set HOME_DIR = ${ROOT_DIR}/SCG.PROC/sproc
        source ${HOME_DIR}/SET.cruise.dirs
endif
set programName = `basename $0`
set RealTimeDir=/scgscg/files/PFILE
foreach data ( ASH DR1 GP90 GRAV HYDRO PCODE SSMAG TRAWL TRIMBLE )
	# default value.  Works for GP90,PCODE,TRIMBLE
	set dir=${DIRUWDATA}/NAV/${data}

	# reset $dir for special cases
	if ( $data == ASH   ) set dir=${DIRUWDATA}/NAV/ASHTECH
	if ( $data == DR1   ) set dir=${DIRUWDATA}/NAV
	if ( $data == GRAV  ) set dir=${DIRUWDATA}/GRAV
	if ( $data == HYDRO ) set dir=${DIRUWDATA}/WINCH
	if ( $data == SSMAG ) set dir=${DIRUWDATA}/MAG
	if ( $data == TRAWL ) set dir=${DIRUWDATA}/WINCH

	echo "rsync'ing ${RealTime}:${RealTimeDir}/${data}* with ${dir}"

	# write a file of files to exclude if a .Z file exists
	set excludeFile=/tmp/${programName}_${data}_${$}_exclude

	# ensure file exists and is blank, to begin with
	if ( -e $excludeFile ) /bin/rm -f $excludeFile
	touch $excludeFile

	set array = `/bin/ls -1 $dir/$data*.Z`
	if ( $#array > 0 ) then
		foreach i ($array)
			set b = $i:t
			set b = $b:r
			echo $b >> $excludeFile
		end
	endif

	# ready to rsync!
	rsync -rlt --exclude-from="${excludeFile}" --include="/${data}*" --exclude="*" ${RealTime}:${RealTimeDir}/ ${dir}

	# delete exclusion file
	/bin/rm -f $excludeFile
end 
